cadnaPromise
==============

.. image:: https://img.shields.io/badge/License-GPLv3-yellowgreen.svg
    :target: LICENSE
    :alt: License


Software for precision auto-tuning of floating-point variables in program

--------
Install
--------

To install ``cadnaPromise``, simply use the pip command:  

.. parsed-literal::

  pip install cadnaPromise


Then to activate the ``cadnaPromise``, use 

.. parsed-literal::

  activate-cadna


